==> giada_0.13.2~dfsg1.orig.tar.gz: giada-0.13.2/src/gui/elems/mainWindow/keyboard/channelButton.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * ge_channelButton
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2016 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef GE_CHANNEL_BUTTON_H
#define GE_CHANNEL_BUTTON_H


#include "../../ge_mixed.h"


class geChannelButton : public gClick
{
private:

	std::string key;

public:

	geChannelButton(int x, int y, int w, int h, const char *l=0);

	virtual int handle(int e) = 0;

	void draw();
	void setKey(const std::string &k);
	void setKey(int k);
	void setPlayMode();
	void setEndingMode();
	void setDefaultMode(const char *l=0);
	void setInputRecordMode();
	void setActionRecordMode();
};


#endif

==> giada_0.14.0~dfsg1.orig.tar.gz: giada-0.14.0/src/gui/elems/mainWindow/keyboard/channelButton.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef GE_CHANNEL_BUTTON_H
#define GE_CHANNEL_BUTTON_H


#include "../../basics/button.h"


class geChannelButton : public geButton
{
private:

	std::string key;

public:

	geChannelButton(int x, int y, int w, int h, const char *l=0);

	virtual int handle(int e) = 0;

	void draw() override;
  
	void setKey(const std::string &k);
	void setKey(int k);
	void setPlayMode();
	void setEndingMode();
	void setDefaultMode(const char *l=0);
	void setInputRecordMode();
	void setActionRecordMode();
};


#endif
